/**
 * Cyklop config file
 */

.pragma library

// General
var VERSION = "0.0.1"; //version

// UI
var MARGIN = 20;
var BGCOLOR_BANER = "#498800";
var BGCOLOR = "#f0f1f2";
var BGCOLOR_DARK = "#e4e5e6";
var BGCOLOR2 = "#50ace5";
var FGCOLOR = "#000000";
var FGCOLOR_BANER = "#ffffff";
var GREEN = "#dd498800";
var YELLOW = "#dde69600";
var RED = "#ddff2a2a";

var FONT_FAMILY = "Arial";
var FONT_SIZE = 24;


